/*
 * Copyright (c) 2002-2018, Mairie de Paris
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice
 *     and the following disclaimer.
 *
 *  2. Redistributions in binary form must reproduce the above copyright notice
 *     and the following disclaimer in the documentation and/or other materials
 *     provided with the distribution.
 *
 *  3. Neither the name of 'Mairie de Paris' nor 'Lutece' nor the names of its
 *     contributors may be used to endorse or promote products derived from
 *     this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * License 1.0
 */
package fr.paris.lutece.plugins.appointment.business.appointment;

import java.util.List;

import fr.paris.lutece.portal.service.plugin.Plugin;

/**
 * Appointment Response DAO Interface
 * 
 * @author Laurent Payen
 *
 */
public interface IAppointmentResponseDAO
{

    /**
     * The name of the bean of the DAO
     */
    static String BEAN_NAME = "appointment.appointmentResponseDAO";

    /**
     * Associates a response to an appointment
     * 
     * @param nIdAppointment
     *            The id of the appointment
     * @param nIdResponse
     *            The id of the response
     * @param plugin
     *            The plugin
     */
    void insertAppointmentResponse( int nIdAppointment, int nIdResponse, Plugin plugin );

    /**
     * Remove an appointment responses from the id of a response.
     * 
     * @param nIdResponse
     *            The id of the response
     * @param plugin
     *            The plugin
     */
    void removeAppointmentResponseByIdResponse( int nIdResponse, Plugin plugin );

    /**
     * Get the list of id of responses associated with an appointment
     * 
     * @param nIdAppointment
     *            the id of the appointment
     * @param plugin
     *            the plugin
     * @return the list of responses, or an empty list if no response was found
     */
    List<Integer> findListIdResponse( int nIdAppointment, Plugin plugin );

}
